@@ -24,7 +24,7 @@ public:
 
 	void setText(QString text);
 	QString getText();
-	void setImage(QImage* image);
+	void setImage(QImage* image, QString type);
 
 	Target * getSource ();
 
@@ -40,7 +40,9 @@ signals:
 	void deleteTarget(Target * source);
 
 private:
-	//void mousePressEvent(QMouseEvent*);
+	//void enterEvent ( QEvent * event );
+	//void leaveEvent ( QEvent * event );
+	
 	void mouseReleaseEvent(QMouseEvent*);
 	void contextMenuEvent (QContextMenuEvent *);
 
@@ -48,7 +50,7 @@ private:
 	QLabel*         label;
 	QHBoxLayout*    layout;
 	Target * source;
-	
+	//void paintEvent(QPaintEvent* event);
 };
 
 
