@@ -5,6 +5,7 @@
 #include "eWallet.h"
 #include "DatabaseManager.h"
 #include <Qt>
+#include <QFile>
 #ifdef Q_WS_MAEMO_5
 //#include <QtMaemo5/QMaemo5KineticScroller>
 #endif
@@ -16,53 +17,12 @@ eWallet::eWallet(QWidget *parent) :
 {
 	::dbManager = new DatabaseManager(this);
 
-	do {
-		if (loginDialogDlg.isNull()) {
-			loginDialogDlg = new LoginDialog(this);
-	#if defined(Q_OS_WIN32)
-			loginDialogDlg->setFixedSize(640,480);
-	#elif defined(Q_WS_HILDON)
-			loginDialogDlg->setMinimumSize(size().width(),size().height()-100);
-	#else
-			loginDialogDlg->showMaximized();
-	#endif
-			loginDialogDlg->exec();
-			delete loginDialogDlg;
-			loginDialogDlg = 0;
-		}
-	}
-	while(!::dbManager->isReady ());
+	askPassword ();
 	
 	setProperty("FingerScrollable", false);
 	//setContextMenuPolicy(Qt::NoContextMenu);
 
-	this->types.append("Credit Card");
-	this->types.append("ID");
-	this->types.append("Others");
-
-	fieldsByType [0].append(TargetField ("Expired Date", TYPE_DATE, true, 1));
-	fieldsByType [0].append(TargetField ("Bank", TYPE_STRING, true, 2));
-	fieldsByType [0].append(TargetField ("PIN", TYPE_INTEGER, true, 3));
-	fieldsByType [0].append(TargetField ("Extra 1", TYPE_STRING, true, 40));
-	fieldsByType [0].append(TargetField ("Extra 2", TYPE_STRING, true, 50));
-	fieldsByType [0].append(TargetField ("Extra 3", TYPE_STRING, true, 60));
-	fieldsByType [0].append(TargetField ("Extra 4", TYPE_STRING, true, 70));
-	fieldsByType [0].append(TargetField ("Extra 5", TYPE_STRING, true, 80));
-
-	fieldsByType [1].append(TargetField ("Issued Date", TYPE_DATE, true, 1));
-	fieldsByType [1].append(TargetField ("Titular", TYPE_STRING, true, 2));
-	fieldsByType [1].append(TargetField ("PIN", TYPE_INTEGER, true, 3));
-	fieldsByType [1].append(TargetField ("Extra 1", TYPE_STRING, true, 40));
-	fieldsByType [1].append(TargetField ("Extra 2", TYPE_STRING, true, 50));
-	fieldsByType [1].append(TargetField ("Extra 3", TYPE_STRING, true, 60));
-	fieldsByType [1].append(TargetField ("Extra 4", TYPE_STRING, true, 70));
-	fieldsByType [1].append(TargetField ("Extra 5", TYPE_STRING, true, 80));
-
-	fieldsByType [2].append(TargetField ("Extra 1", TYPE_STRING, true, 40));
-	fieldsByType [2].append(TargetField ("Extra 2", TYPE_STRING, true, 50));
-	fieldsByType [2].append(TargetField ("Extra 3", TYPE_STRING, true, 60));
-	fieldsByType [2].append(TargetField ("Extra 4", TYPE_STRING, true, 70));
-	fieldsByType [2].append(TargetField ("Extra 5", TYPE_STRING, true, 80));
+	loadTypesAndFields ();
 
 	//                         // Central widget and Layout
 	centralWidget = new QWidget(this);
@@ -85,6 +45,16 @@ eWallet::eWallet(QWidget *parent) :
 	createMenu ();
 
 	centralWidget->setFocus ();
+	
+
+	timer = new QTimer(this);
+	//TODO connect(timer, SIGNAL(timeout()), this, SLOT(lockWallet()));
+    //TODO timer->start(5000);
+}
+
+void eWallet::lockWallet () {
+	::dbManager->lock ();
+	askPassword ();
 }
 
 bool eWallet::openDataBase (QString pas)
@@ -97,6 +67,84 @@ eWallet::~eWallet ()
 	delete ::dbManager;
 }
 
+void eWallet::loadTypesAndFields () {
+	  QFile file(":/resources/types.txt");
+	  QString line;
+
+	  if ( file.open(QIODevice::Text | QIODevice::ReadOnly) ) {
+	    // file opened successfully
+	    QTextStream t(&file);        // use a text stream
+	    // until end of file...
+	    int i = 0;
+	    while ( !t.atEnd() ) {
+	      // read and parse the command line
+	      QString line = t.readLine();         // line of text excluding '\n'
+	      // do something with the line
+
+	      if (line.length() > 0) {
+	    	  if ((i++) == 0) {
+	    		  this->types.append(line);
+	    		  this->fieldsByType.append (new QList<TargetField>);
+				  qDebug () << " new type "<< line << " " << this->types.length();
+	    	  }
+	    	  else {
+	    		  // TODO implements types
+	    		  this->fieldsByType [this->types.length() - 1]->append(TargetField (line, TYPE_STRING, true, i));
+				  qDebug () << " new field "<< line << " " << this->types.length();
+	    	  }
+	      }
+	      else {
+	    	  i = 0;
+	      }
+
+	    }
+
+	    // Close the file
+	    file.close();
+	  }
+}
+
+//
+//	this->types.append("Credit Card");
+//	this->types.append("Membership Info");
+//	this->types.append("Password");
+//	this->types.append("Bank Account");
+//	this->types.append("Cellular Phone");
+//	this->types.append("Web Site");
+//	this->types.append("Health Numbers");
+//	this->types.append("Passport Info");
+//	this->types.append("Note Card");
+//	this->types.append("Car Info");
+//	this->types.append("ID Card");
+//	this->types.append("Social Security Number");
+//	this->types.append("Driver's License");
+//	this->types.append("Email Account");
+//	this->types.append("Others");
+//
+//	fieldsByType [0].append(TargetField ("Expired Date", TYPE_DATE, true, 1));
+//	fieldsByType [0].append(TargetField ("Bank", TYPE_STRING, true, 2));
+//	fieldsByType [0].append(TargetField ("PIN", TYPE_INTEGER, true, 3));
+//	fieldsByType [0].append(TargetField ("Extra 1", TYPE_STRING, true, 40));
+//	fieldsByType [0].append(TargetField ("Extra 2", TYPE_STRING, true, 50));
+//	fieldsByType [0].append(TargetField ("Extra 3", TYPE_STRING, true, 60));
+//	fieldsByType [0].append(TargetField ("Extra 4", TYPE_STRING, true, 70));
+//	fieldsByType [0].append(TargetField ("Extra 5", TYPE_STRING, true, 80));
+//
+//	fieldsByType [1].append(TargetField ("Issued Date", TYPE_DATE, true, 1));
+//	fieldsByType [1].append(TargetField ("Titular", TYPE_STRING, true, 2));
+//	fieldsByType [1].append(TargetField ("PIN", TYPE_INTEGER, true, 3));
+//	fieldsByType [1].append(TargetField ("Extra 1", TYPE_STRING, true, 40));
+//	fieldsByType [1].append(TargetField ("Extra 2", TYPE_STRING, true, 50));
+//	fieldsByType [1].append(TargetField ("Extra 3", TYPE_STRING, true, 60));
+//	fieldsByType [1].append(TargetField ("Extra 4", TYPE_STRING, true, 70));
+//	fieldsByType [1].append(TargetField ("Extra 5", TYPE_STRING, true, 80));
+//
+//	fieldsByType [2].append(TargetField ("Extra 1", TYPE_STRING, true, 40));
+//	fieldsByType [2].append(TargetField ("Extra 2", TYPE_STRING, true, 50));
+//	fieldsByType [2].append(TargetField ("Extra 3", TYPE_STRING, true, 60));
+//	fieldsByType [2].append(TargetField ("Extra 4", TYPE_STRING, true, 70));
+//	fieldsByType [2].append(TargetField ("Extra 5", TYPE_STRING, true, 80));
+
 
 
 void eWallet::timerEvent(QTimerEvent* event)
@@ -155,16 +203,10 @@ void eWallet::showTargets()
 
 void eWallet::createMenu()
 {
-#if defined(Q_OS_SYMBIAN) || defined(Q_WS_HILDON)
 	menuBar()->addAction("New", this, SLOT(newTarget()));
-//	menuBar()->addAction("Edit", this, SLOT(editTarget()));
+	menuBar()->addAction("Import", this, SLOT(import()));
 	menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
-#else
-	QMenu* optionsMenu = menuBar()->addMenu(tr("&File"));
-	optionsMenu->addAction("New", this, SLOT(newTarget()));
-	//optionsMenu->addAction("Edit", this, SLOT(editTarget()));
-	optionsMenu->addAction("Exit", QApplication::instance(), SLOT(quit()));
-#endif
+
 }
 /*
 void eWallet::newTarget()
@@ -245,7 +287,7 @@ bool eWallet::_updateTargetPicture(Target* target)
 {
 	if (::dbManager->updateTargetPicture(target)) {
 		if (row >= 0) {
-			fnListWidget->itemAt (row)->setImage (target->picture);
+			fnListWidget->itemAt (row)->setImage (target->picture, target->type);
 		}
 		return true;
 	}
@@ -331,6 +373,83 @@ void eWallet::editTarget(Target * rent) {
 	}
 }
 
+void eWallet::import() {
+	QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
+	QString s = QFileDialog::getOpenFileName(
+	                this,
+	                "Choose import file",
+	                path,
+	                "Text (*.txt)");
+	if (!s.isNull () && !s.isEmpty ()) {
+
+		  QFile file(s);
+		  QString line;
+
+		  Target * target = NULL;
+		  if ( file.open(QIODevice::Text | QIODevice::ReadOnly) ) {
+		    // file opened successfully
+		    QTextStream t(&file);        // use a text stream
+		    // until end of file...
+		    int i = 0;
+		    while ( !t.atEnd() ) {
+		      // read and parse the command line
+		      QString line = t.readLine();         // line of text excluding '\n'
+		      // do something with the line
+
+		      if (line.length() > 0) {
+		    	  if (target == NULL) {
+		    		  target = new Target ();
+		    	  }
+
+		    	  int j = line.indexOf(QChar(':'));
+		    	  if (j > 0) {
+					  switch (i++) {
+					  case 0:
+						  target->name = line.mid(j + 1).trimmed();
+						  break;
+					  case 1:
+						  // TODO check type with existing one!
+						  target->type = line.mid(j + 1).trimmed();
+						  break;
+					  default:
+						  TargetField * field = new TargetField ();
+						  field->name = line.mid (0, j).trimmed();
+						  field->value = line.mid(j + 1).trimmed();
+						  field->encrypted = true;
+						  field->type = TYPE_STRING;
+						  target->fields.append(field);
+					  }
+
+					  qDebug () << line << " | " << line.mid(j + 1) << " IS " << line.mid (0, j);
+		    	  }
+		    	  else {
+		    		  if (target != NULL && target->fields.size() > 0) {
+		    			  target->fields.last()->value.append("\n").append (line);
+		    			  target->fields.last()->type = TYPE_TEXT;
+		    		  }
+		    	  }
+		      }
+		      else {
+		    	  if (target != NULL) {
+		    		  this->_insertTarget(target);
+		    	  }
+		    	  target = NULL;
+		    	  i = 0;
+		      }
+
+		      qDebug () << line;
+		    }
+
+			 if (target != NULL) {
+				  this->_insertTarget(target);
+			 }
+		    // Close the file
+		    file.close();
+		  }
+
+	}
+}
+
 void eWallet::newTarget() {
 	qDebug()<<"new ";
 
@@ -397,3 +516,46 @@ void eWallet::_viewcTarget() {
 	viewTarget(this->fnListWidget->itemAt(row)->getSource());
 }
 
+//eWallet closeEvent function:
+void eWallet::closeEvent(QCloseEvent *event){
+	qDebug () << "close Event";
+        //saveSettings();
+        event->accept();
+}
+
+void eWallet::askPassword () {
+	int times = 0;
+	
+	do {
+		if (loginDialogDlg.isNull()) {
+			loginDialogDlg = new LoginDialog(this);
+	#if defined(Q_OS_WIN32)
+			loginDialogDlg->setFixedSize(640,480);
+	#elif defined(Q_WS_HILDON)
+			loginDialogDlg->setMinimumSize(size().width(),size().height()-100);
+	#else
+			loginDialogDlg->showMaximized();
+	#endif
+			loginDialogDlg->exec();
+			delete loginDialogDlg;
+			loginDialogDlg = 0;
+		}
+		
+		//qDebug () << "TIME " << times;
+			
+		if (++times > 3) {
+			exit(3);
+		}
+		else {
+			if (!::dbManager->isReady ()) {
+				if (messageBox.isNull()) {
+					messageBox = new QMessageBox(this);
+					messageBox->information(this, "Wallet", "Wrong password", QMessageBox::Ok);
+				}
+				delete messageBox;
+				messageBox = 0;
+			}
+		}
+	}
+	while(!::dbManager->isReady ());
+}
