@@ -14,6 +14,7 @@
 #include "DetailedWindow.h"
 #include "LoginDialog.h"
 
+#define TYPE_TEXT 3
 #define TYPE_DATE 2
 #define TYPE_STRING 0
 #define TYPE_INTEGER 1
@@ -40,10 +41,11 @@ public:
 	bool _insertTarget(Target* target);
 	
 	QList<QString> types;
-	QList<TargetField> fieldsByType [3];
+	QList<QList<TargetField>*> fieldsByType;
 
 public slots:
 	void newTarget();
+	void import();
 	void editTarget(Target * t);
 	void deleteTarget(Target * t);
 	void viewTarget(Target * t);
@@ -51,6 +53,7 @@ public slots:
 private:
 	void createMenu();
 	void showTargets();
+	void loadTypesAndFields ();
 	//void contextMenuEvent (QContextMenuEvent * event);
 
 private slots:
@@ -58,10 +61,13 @@ private slots:
 	void _editcTarget();
 	void _deletecTarget();
 	void _viewcTarget();
-
+	void lockWallet ();
 	
 private:
-	//Target * activeTarget();
+	//void timerEvent(QTimerEvent *event);
+	void askPassword ();
+	void closeEvent(QCloseEvent *event);
+	
 	QVBoxLayout* vboxlayout;
 
 	QFNListWidget* fnListWidget;
@@ -72,10 +78,12 @@ private:
 	QPointer<DetailWindow> detailWindow;
 	QPointer<DetailWindow> detailWindowEdit;
 	QWidget* centralWidget;
-
+	QPointer <QMessageBox> messageBox;
 	bool opendb;
 	bool initdb;
 	
 	int row;
+	
+	QTimer *timer;
 };
 #endif // EWALLET_H
